require 'uu/os/rest/dto'
require 'uu/os/uesuri'

# Module Unicorn Universe
module UU

  # Module Finman
  module Finman

    # Module of finman Financial transaction
    module FinancialTransaction

      # DTO for get attributes command of credit note.
      class CreditNoteAttributes < UU::OS::REST::DTO

        # URI of the financial transaction.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :uri

        # URI of meta artifact of the financial transaction.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :meta_artifact_uri

        # Name of the financial transaction.
        # @param [String]
        # @return [String]
        attr_accessor :name

        # Code of the financial transaction.
        # @param [String]
        # @return [String]
        attr_accessor :code

        # Description of the financial transaction.
        # @param [String]
        # @return [String]
        attr_accessor :description

        # URI of role competent for the financial transaction.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :competent_role_uri

        # URI of container of the financial transaction.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :location_uri

        # URI of organizational unit of the financial transaction.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :organizational_unit_uri

        # Type of the financial transaction artifact.
        # @param [String, UU::OS::Artifact::ArtifactType]
        # @return [UU::OS::Artifact::ArtifactType]
        attr_accessor :artifact_type

        # Security level of the financial transaction.
        # @param [String, UU::OS::Artifact::SecurityLevel]
        # @return [UU::OS::Artifact::SecurityLevel]
        attr_accessor :security_level

        # Creation stamp of the financial transaction.
        # @param [String]
        # @return [String]
        attr_accessor :creation_stamp

        # Creation time of the financial transaction.
        # @param [String, Time]
        # @return [String]
        attr_accessor :creation_time

        # Modification stamp of the financial transaction.
        # @param [String]
        # @return [String]
        attr_accessor :modification_stamp

        # Modification time of the financial transaction.
        # @param [String, Time]
        # @return [String]
        attr_accessor :modification_time

        # Version of the financial transaction.
        # @param [String]
        # @return [String]
        attr_accessor :version

        # Name of current state of the financial transaction.
        # @param [String]
        # @return [String]
        attr_accessor :state_name

        # Comment of current state of the financial transaction.
        # @param [String]
        # @return [String]
        attr_accessor :state_comment

        # Type of current state of the financial transaction.
        # @param [UU::OS::Artifact::ArtifactStateType]
        # @return [UU::OS::Artifact::ArtifactStateType]
        attr_accessor :state_type

        # Flag of width of sheets of the financial transaction.
        # @param [String]
        # @return [String]
        attr_accessor :width

        # URI of the icon of the financial transaction.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :icon_uri

        # UESURI of the entity type of the artifact
        # @param [String]
        # @return [String]
        attr_accessor :entity_type_uri

        # Amount of the Financial Transaction without vat.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :amount_without_vat

        # Amount of the Financial Transaction with vat.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :amount_with_vat

        # Constant symbol.
        # @param [String]
        # @return [String]
        attr_accessor :constant_symbol

        # Specifies type of credit note.
        # @param [CreditNoteType]
        # @return [CreditNoteType]
        attr_accessor :credit_note_type

        # UESURI of Contract.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :contract_uri

        # Code of cost item.
        # @param [String]
        # @return [String]
        attr_accessor :cost_item_code

        # Number of supplier account.
        # @param [String]
        # @return [String]
        attr_accessor :supplier_account_number

        # UESURI of supplier account artifact.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :supplier_account_uri

        # UESURI of supplier business case from opposite territory.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :supplier_business_case_from_opposite_territory

        # UESURI of the supplier business case
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :supplier_business_case_uri

        # Description for supplier side.
        # @param [String]
        # @return [String]
        attr_accessor :supplier_description

        # UESURI of supplier financial category.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :supplier_financial_category_uri

        # Supplier vat date of the transaction.
        # @param [String, Time]
        # @return [String]
        attr_accessor :supplier_vat_date

        # Number of client account.
        # @param [String]
        # @return [String]
        attr_accessor :client_account_number

        # UESURI of client account artifact.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :client_account_uri

        # UESURI of client business case from opposite territory.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :client_business_case_from_opposite_territory

        # UESURI of the client business case.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :client_business_case_uri

        # Description for client side.
        # @param [String]
        # @return [String]
        attr_accessor :client_description

        # UESURI of client financial category.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :client_financial_category_uri

        # Client vat date of the transaction.
        # @param [String, Time]
        # @return [String]
        attr_accessor :client_vat_date

        # Date the payment is due to be paid.
        # @param [String, Time]
        # @return [String]
        attr_accessor :due_date

        # Date the payment is expected to be payed to.
        # @param [String, Time]
        # @return [String]
        attr_accessor :expected_pay_date

        # Type of financial transaction. Item from enumeration {FinancialTransactionType}
        # Possible values: CASH or NONCASH
        # @param [FinancialTransactionType]
        # @return [FinancialTransactionType]
        attr_accessor :financial_transaction_type

        # Class of financial transaction (specifies if it is Payment, Transfer, Expost payment or Credit note)
        # @param [FinancialTransactionClass]
        # @return [FinancialTransactionClass]
        attr_accessor :financial_transaction_class

        # Date the accept payment activity will be planned to.
        # @param [String, Time]
        # @return [String]
        attr_accessor :for_acceptance_date

        # Code of income item.
        # @param [String]
        # @return [String]
        attr_accessor :income_item_code

        # Invoice number of financial transaction.
        # @param [String]
        # @return [String]
        attr_accessor :invoice_number

        # UESURI of payment copy artifact.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :interterritorial_payment_copy_uri

        # UESURI of payment original artifact.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :interterritorial_payment_original_uri

        # Original amount of the Financial Transaction with vat.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :original_amount_with_vat

        # Original currency code.
        # @param [String]
        # @return [String]
        attr_accessor :original_currency

        # Pay date of the transaction.
        # @param [String, Time]
        # @return [String]
        attr_accessor :pay_date

        # Date of invoicing to the counterparty.
        # @param [String, Time]
        # @return [String]
        attr_accessor :protocol_date

        # Probability of payment realization in %.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :realization_probability

        # Specifies whether is it needed to approve the credit note by competent manager.
        # @param [TrueClass, FalseClass]
        # @return [TrueClass, FalseClass]
        attr_accessor :request_approval_by_manager

        # Specific symbol.
        # @param [String]
        # @return [String]
        attr_accessor :specific_symbol

        # Variable symbol.
        # @param [String]
        # @return [String]
        attr_accessor :variable_symbol

        # Vat rate.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :vat_rate

        # Specifies whether is it needed to confirm the acceptance of the credit note by client's accountant.
        # @param [TrueClass, FalseClass]
        # @return [TrueClass, FalseClass]
        attr_accessor :wait_for_acceptance_by_accountant

        def uri
          attributes[:uri]
        end

        def uri=(val)
          if val
            attributes[:uri] = UU::OS::UESURI.new(val)
          else
            attributes[:uri] = nil
          end
        end

        def meta_artifact_uri
          attributes[:metaArtifactUri]
        end

        def meta_artifact_uri=(val)
          if val
            attributes[:metaArtifactUri] = UU::OS::UESURI.new(val)
          else
            attributes[:metaArtifactUri] = nil
          end
        end

        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end

        def code
          attributes[:code]
        end

        def code=(val)
          attributes[:code] = val
        end

        def description
          attributes[:description]
        end

        def description=(val)
          attributes[:description] = val
        end

        def competent_role_uri
          attributes[:competentRoleUri]
        end

        def competent_role_uri=(val)
          if val
            attributes[:competentRoleUri] = UU::OS::UESURI.new(val)
          else
            attributes[:competentRoleUri] = nil
          end
        end

        def location_uri
          attributes[:locationUri]
        end

        def location_uri=(val)
          if val
            attributes[:locationUri] = UU::OS::UESURI.new(val)
          else
            attributes[:locationUri] = nil
          end
        end

        def organizational_unit_uri
          attributes[:organizationalUnitUri]
        end

        def organizational_unit_uri=(val)
          if val
            attributes[:organizationalUnitUri] = UU::OS::UESURI.new(val)
          else
            attributes[:organizationalUnitUri] = nil
          end
        end

        def artifact_type
          attributes[:artifactType]
        end

        def artifact_type=(val)
          attributes[:artifactType] = val
        end

        def security_level
          attributes[:securityLevel]
        end

        def security_level=(val)
          attributes[:securityLevel] = val
        end

        def creation_stamp
          attributes[:creationStamp]
        end

        def creation_stamp=(val)
          attributes[:creationStamp] = val
        end

        def creation_time
          attributes[:creationTime]
        end

        def creation_time=(val)
          attributes[:creationTime] = val
        end

        def modification_stamp
          attributes[:modificationStamp]
        end

        def modification_stamp=(val)
          attributes[:modificationStamp] = val
        end

        def modification_time
          attributes[:modificationTime]
        end

        def modification_time=(val)
          attributes[:modificationTime] = val
        end

        def version
          attributes[:version]
        end

        def version=(val)
          attributes[:version] = val
        end

        def state_name
          attributes[:stateName]
        end

        def state_name=(val)
          attributes[:stateName] = val
        end

        def state_comment
          attributes[:stateComment]
        end

        def state_comment=(val)
          attributes[:stateComment] = val
        end

        def state_type
          attributes[:stateType]
        end

        def state_type=(val)
          attributes[:stateType] = val
        end

        def width
          attributes[:width]
        end

        def width=(val)
          attributes[:width] = val
        end

        def icon_uri
          attributes[:iconUri]
        end

        def icon_uri=(val)
          if val
            attributes[:iconUri] = UU::OS::UESURI.new(val)
          else
            attributes[:iconUri] = nil
          end
        end

        def entity_type_uri
          attributes[:entityTypeUri]
        end

        def entity_type_uri=(val)
          if val
            attributes[:entityTypeUri] = UU::OS::UESURI.new(val)
          else
            attributes[:entityTypeUri] = nil
          end
        end

        def amount_without_vat
          attributes[:amountWithoutVat]
        end

        def amount_without_vat=(val)
          attributes[:amountWithoutVat] = val
        end

        def amount_with_vat
          attributes[:amountWithVat]
        end

        def amount_with_vat=(val)
          attributes[:amountWithVat] = val
        end

        def constant_symbol
          attributes[:constantSymbol]
        end

        def constant_symbol=(val)
          attributes[:constantSymbol] = val
        end

        def credit_note_type
          attributes[:creditNoteType]
        end

        def credit_note_type=(val)
          attributes[:creditNoteType] = val
        end

        def contract_uri
          attributes[:contractUri]
        end

        def contract_uri=(val)
          if val
            attributes[:contractUri] = UU::OS::UESURI.new(val)
          else
            attributes[:contractUri] = nil
          end
        end

        def cost_item_code
          attributes[:costItemCode]
        end

        def cost_item_code=(val)
          attributes[:costItemCode] = val
        end

        def supplier_account_number
          attributes[:supplierAccountNumber]
        end

        def supplier_account_number=(val)
          attributes[:supplierAccountNumber] = val
        end

        def supplier_account_uri
          attributes[:supplierAccountUri]
        end

        def supplier_account_uri=(val)
          if val
            attributes[:supplierAccountUri] = UU::OS::UESURI.new(val)
          else
            attributes[:supplierAccountUri] = nil
          end
        end

        def supplier_business_case_from_opposite_territory
          attributes[:supplierBusinessCaseFromOppositeTerritory]
        end

        def supplier_business_case_from_opposite_territory=(val)
          attributes[:supplierBusinessCaseFromOppositeTerritory] = val
        end

        def supplier_business_case_uri
          attributes[:supplierBusinessCaseUri]
        end

        def supplier_business_case_uri=(val)
          if val
            attributes[:supplierBusinessCaseUri] = UU::OS::UESURI.new(val)
          else
            attributes[:supplierBusinessCaseUri] = nil
          end
        end

        def supplier_description
          attributes[:supplierDescription]
        end

        def supplier_description=(val)
          attributes[:supplierDescription] = val
        end

        def supplier_financial_category_uri
          attributes[:supplierFinancialCategoryUri]
        end

        def supplier_financial_category_uri=(val)
          if val
            attributes[:supplierFinancialCategoryUri] = UU::OS::UESURI.new(val)
          else
            attributes[:supplierFinancialCategoryUri] = nil
          end
        end

        def supplier_vat_date
          attributes[:supplierVatDate]
        end

        def supplier_vat_date=(val)
          attributes[:supplierVatDate] = val
        end

        def client_account_number
          attributes[:clientAccountNumber]
        end

        def client_account_number=(val)
          attributes[:clientAccountNumber] = val
        end

        def client_account_uri
          attributes[:clientAccountUri]
        end

        def client_account_uri=(val)
          if val
            attributes[:clientAccountUri] = UU::OS::UESURI.new(val)
          else
            attributes[:clientAccountUri] = nil
          end
        end

        def client_business_case_from_opposite_territory
          attributes[:clientBusinessCaseFromOppositeTerritory]
        end

        def client_business_case_from_opposite_territory=(val)
          attributes[:clientBusinessCaseFromOppositeTerritory] = val
        end

        def client_business_case_uri
          attributes[:clientBusinessCaseUri]
        end

        def client_business_case_uri=(val)
          if val
            attributes[:clientBusinessCaseUri] = UU::OS::UESURI.new(val)
          else
            attributes[:clientBusinessCaseUri] = nil
          end
        end

        def client_description
          attributes[:clientDescription]
        end

        def client_description=(val)
          attributes[:clientDescription] = val
        end

        def client_financial_category_uri
          attributes[:clientFinancialCategoryUri]
        end

        def client_financial_category_uri=(val)
          if val
            attributes[:clientFinancialCategoryUri] = UU::OS::UESURI.new(val)
          else
            attributes[:clientFinancialCategoryUri] = nil
          end
        end

        def client_vat_date
          attributes[:clientVatDate]
        end

        def client_vat_date=(val)
          attributes[:clientVatDate] = val
        end

        def due_date
          attributes[:dueDate]
        end

        def due_date=(val)
          attributes[:dueDate] = val
        end

        def expected_pay_date
          attributes[:expectedPayDate]
        end

        def expected_pay_date=(val)
          attributes[:expectedPayDate] = val
        end

        def financial_transaction_type
          attributes[:financialTransactionType]
        end

        def financial_transaction_type=(val)
          attributes[:financialTransactionType] = val
        end

        def financial_transaction_class
          attributes[:financialTransactionClass]
        end

        def financial_transaction_class=(val)
          attributes[:financialTransactionClass] = val
        end

        def for_acceptance_date
          attributes[:forAcceptanceDate]
        end

        def for_acceptance_date=(val)
          attributes[:forAcceptanceDate] = val
        end

        def income_item_code
          attributes[:incomeItemCode]
        end

        def income_item_code=(val)
          attributes[:incomeItemCode] = val
        end

        def invoice_number
          attributes[:invoiceNumber]
        end

        def invoice_number=(val)
          attributes[:invoiceNumber] = val
        end

        def interterritorial_payment_copy_uri
          attributes[:interterritorialPaymentCopyUri]
        end

        def interterritorial_payment_copy_uri=(val)
          if val
            attributes[:interterritorialPaymentCopyUri] = UU::OS::UESURI.new(val)
          else
            attributes[:interterritorialPaymentCopyUri] = nil
          end
        end

        def interterritorial_payment_original_uri
          attributes[:interterritorialPaymentOriginalUri]
        end

        def interterritorial_payment_original_uri=(val)
          if val
            attributes[:interterritorialPaymentOriginalUri] = UU::OS::UESURI.new(val)
          else
            attributes[:interterritorialPaymentOriginalUri] = nil
          end
        end

        def original_amount_with_vat
          attributes[:originalAmountWithVat]
        end

        def original_amount_with_vat=(val)
          attributes[:originalAmountWithVat] = val
        end

        def original_currency
          attributes[:originalCurrency]
        end

        def original_currency=(val)
          attributes[:originalCurrency] = val
        end

        def pay_date
          attributes[:payDate]
        end

        def pay_date=(val)
          attributes[:payDate] = val
        end

        def protocol_date
          attributes[:protocolDate]
        end

        def protocol_date=(val)
          attributes[:protocolDate] = val
        end

        def realization_probability
          attributes[:realizationProbability]
        end

        def realization_probability=(val)
          attributes[:realizationProbability] = val
        end

        def request_approval_by_manager
          attributes[:requestApprovalByManager]
        end

        def request_approval_by_manager=(val)
          attributes[:requestApprovalByManager] = val
        end

        def specific_symbol
          attributes[:specificSymbol]
        end

        def specific_symbol=(val)
          attributes[:specificSymbol] = val
        end

        def variable_symbol
          attributes[:variableSymbol]
        end

        def variable_symbol=(val)
          attributes[:variableSymbol] = val
        end

        def vat_rate
          attributes[:vatRate]
        end

        def vat_rate=(val)
          attributes[:vatRate] = val
        end

        def wait_for_acceptance_by_accountant
          attributes[:waitForAcceptanceByAccountant]
        end

        def wait_for_acceptance_by_accountant=(val)
          attributes[:waitForAcceptanceByAccountant] = val
        end

      end
    end
  end
end
