require 'uu/os/rest/dto'
require 'uu/os/uesuri'

# Module Unicorn Universe
module UU

  # Module Finman
  module Finman

    # Module of finman Fast Payment
    module FinancialTransaction

      # DTO for create command of Fast Payment.
      class FastPaymentCreate < UU::OS::REST::DTO

        # Name of created Payment. Required attribute. Cannot be null or empty.
        # @param [String]
        # @return [String]
        attr_accessor :name

        # Amount of the Fast Payment without vat.
        # Required attribute. Cannot be null.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :amount_without_vat

        # Amount of the Fast Payment with vat.
        # Either amount with vat or vat rate must be set.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :amount_with_vat

        # Constant symbol.
        # @param [String]
        # @return [String]
        attr_accessor :constant_symbol

        # UESURI of Contract.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :contract_uri

        # Code of cost item.
        # @param [String]
        # @return [String]
        attr_accessor :cost_item_code

        # UESURI of the business case of non-control side of paynment.
        # Required attribute. Cannot be null.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :counterparty_business_case_uri

        # Number of credit account.
        # Either number or UESURI of account must be set. Not both of them.
        # @param [String]
        # @return [String]
        attr_accessor :credit_account_number

        # UESURI of credit account artifact.
        # Either number or UESURI of account must be set. Not both of them.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :credit_account_uri

        # UESURI of credit business case from opposite territory.
        # Usable only for interterritorial payments.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :credit_business_case_from_opposite_territory

        # Description for credit side.
        # @param [String]
        # @return [String]
        attr_accessor :credit_description

        # UESURI of credit financial category.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :credit_financial_category_uri

        # Number of debit account.
        # Either number or UESURI of account must be set. Not both of them.
        # @param [String]
        # @return [String]
        attr_accessor :debit_account_number

        # UESURI of debit account artifact.
        # Either number or UESURI of account must be set. Not both of them.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :debit_account_uri

        # UESURI of debit business case from opposite territory.
        # Usable only for interterritorial payments.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :debit_business_case_from_opposite_territory

        # Description for debit side.
        # @param [String]
        # @return [String]
        attr_accessor :debit_description

        # UESURI of debit financial category.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :debit_financial_category_uri

        # Date the payment is due to be paid.
        # Required attribute. Cannot be null.
        # @param [String, Time]
        # @return [String]
        attr_accessor :due_date

        # Date the payment is expected to be paid to.
        # Required attribute. Cannot be null.
        # @param [String, Time]
        # @return [String]
        attr_accessor :expected_pay_date

        # Type of Fast Payment. Item from enumeration {UU::Finman::FinancialTransaction::FinancialTransactionType}.
        # Required attribute. Cannot be null. Following rules must be obeyed:
        #
        # If both UESURI of debit and credit account are set, then:
        # - if both accounts are Bank accounts, FinancialTransactionType.NONCASH must be set.
        # - if at least one account is Cash account, FinancialTransactionType.CASH must be set.
        # Otherwise any choice can be set.
        # @param [String, FinancialTransactionType]
        # @return [String]
        attr_accessor :financial_transaction_type

        # Code of income item.
        # @param [String]
        # @return [String]
        attr_accessor :income_item_code

        # Invoice number of Fast Payment.
        # @param [String]
        # @return [String]
        attr_accessor :invoice_number

        # Original amount of the Fast Payment with vat.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :original_amount_with_vat

        # Original currency code.
        # @param [String]
        # @return [String]
        attr_accessor :original_currency

        # Probability of Fast Payment realization in %.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :realization_probability

        # Specific symbol.
        # @param [String]
        # @return [String]
        attr_accessor :specific_symbol

        # Variable symbol.
        # @param [String]
        # @return [String]
        attr_accessor :variable_symbol

        # Vat rate.
        # Either amount with vat or vat rate must be set.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :vat_rate

        # Close after creation
        # @param [TrueClass, FalseClass]
        # @return [TrueClass, FalseClass]
        attr_accessor :close_after_creation

        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end

        def amount_without_vat
          attributes[:amountWithoutVat]
        end

        def amount_without_vat=(val)
          attributes[:amountWithoutVat] = val
        end

        def amount_with_vat
          attributes[:amountWithVat]
        end

        def amount_with_vat=(val)
          attributes[:amountWithVat] = val
        end

        def constant_symbol
          attributes[:constantSymbol]
        end

        def constant_symbol=(val)
          attributes[:constantSymbol] = val
        end

        def contract_uri
          attributes[:contractUri]
        end

        def contract_uri=(val)
          if val
            attributes[:contractUri] = UU::OS::UESURI.new(val)
          else
            attributes[:contractUri] = nil
          end
        end

        def cost_item_code
          attributes[:costItemCode]
        end

        def cost_item_code=(val)
          attributes[:costItemCode] = val
        end

        def counterparty_business_case_uri
          attributes[:counterpartyBusinessCaseUri]
        end

        def counterparty_business_case_uri=(val)
          if val
            attributes[:counterpartyBusinessCaseUri] = UU::OS::UESURI.new(val)
          else
            attributes[:counterpartyBusinessCaseUri] = nil
          end
        end

        def credit_account_number
          attributes[:creditAccountNumber]
        end

        def credit_account_number=(val)
          attributes[:creditAccountNumber] = val
        end

        def credit_account_uri
          attributes[:creditAccountUri]
        end

        def credit_account_uri=(val)
          if val
            attributes[:creditAccountUri] = UU::OS::UESURI.new(val)
          else
            attributes[:creditAccountUri] = nil
          end
        end

        def credit_business_case_from_opposite_territory
          attributes[:creditBusinessCaseFromOppositeTerritory]
        end

        def credit_business_case_from_opposite_territory=(val)
          attributes[:creditBusinessCaseFromOppositeTerritory] = val
        end

        def credit_description
          attributes[:creditDescription]
        end

        def credit_description=(val)
          attributes[:creditDescription] = val
        end

        def credit_financial_category_uri
          attributes[:creditFinancialCategoryUri]
        end

        def credit_financial_category_uri=(val)
          attributes[:creditFinancialCategoryUri] = val
        end

        def debit_account_number
          attributes[:debitAccountNumber]
        end

        def debit_account_number=(val)
          attributes[:debitAccountNumber] = val
        end

        def debit_account_uri
          attributes[:debitAccountUri]
        end

        def debit_account_uri=(val)
          if val
            attributes[:debitAccountUri] = UU::OS::UESURI.new(val)
          else
            attributes[:debitAccountUri] = nil
          end
        end

        def debit_business_case_from_opposite_territory
          attributes[:debitBusinessCaseFromOppositeTerritory]
        end

        def debit_business_case_from_opposite_territory=(val)
          attributes[:debitBusinessCaseFromOppositeTerritory] = val
        end

        def debit_description
          attributes[:debitDescription]
        end

        def debit_description=(val)
          attributes[:debitDescription] = val
        end

        def debit_financial_category_uri
          attributes[:debitFinancialCategoryUri]
        end

        def debit_financial_category_uri=(val)
          attributes[:debitFinancialCategoryUri] = val
        end

        def due_date
          attributes[:dueDate]
        end

        def due_date=(val)
          attributes[:dueDate] = val
        end

        def expected_pay_date
          attributes[:expectedPayDate]
        end

        def expected_pay_date=(val)
          attributes[:expectedPayDate] = val
        end

        def financial_transaction_type
          attributes[:financialTransactionType]
        end

        def financial_transaction_type=(val)
          attributes[:financialTransactionType] = val
        end

        def income_item_code
          attributes[:incomeItemCode]
        end

        def income_item_code=(val)
          attributes[:incomeItemCode] = val
        end

        def invoice_number
          attributes[:invoiceNumber]
        end

        def invoice_number=(val)
          attributes[:invoiceNumber] = val
        end

        def original_amount_with_vat
          attributes[:originalAmountWithVat]
        end

        def original_amount_with_vat=(val)
          attributes[:originalAmountWithVat] = val
        end

        def original_currency
          attributes[:originalCurrency]
        end

        def original_currency=(val)
          attributes[:originalCurrency] = val
        end

        def realization_probability
          attributes[:realizationProbability]
        end

        def realization_probability=(val)
          attributes[:realizationProbability] = val
        end

        def specific_symbol
          attributes[:specificSymbol]
        end

        def specific_symbol=(val)
          attributes[:specificSymbol] = val
        end

        def variable_symbol
          attributes[:variableSymbol]
        end

        def variable_symbol=(val)
          attributes[:variableSymbol] = val
        end

        def vat_rate
          attributes[:vatRate]
        end

        def vat_rate=(val)
          attributes[:vatRate] = val
        end

        def close_after_creation
          attributes[:closeAfterCreation]
        end

        def close_after_creation=(val)
          attributes[:closeAfterCreation] = val
        end
      end
    end
  end
end
